#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-quickcheck2
version:              0.3.0.5
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.5-Et0vRefXi5ZCLdEv0og4sD
key:                  test-framework-quickcheck2-0.3.0.5-Et0vRefXi5ZCLdEv0og4sD
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://haskell.github.io/test-framework/
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  d3fe5ac1319f1a2fdb9391aed231d7a8
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-8.10.5/site-local/test-framework-quickcheck2-0.3.0.5

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/test-framework-quickcheck2-0.3.0.5

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/test-framework-quickcheck2-0.3.0.5

hs-libraries:         HStest-framework-quickcheck2-0.3.0.5-Et0vRefXi5ZCLdEv0og4sD
depends:
    QuickCheck-2.14.2-LYkEXWaccd95SoKseYSYTk base-4.14.2.0
    extensible-exceptions-0.1.1.4-9nRdO96RVgFCedKm18TbaI
    random-1.2.0-BSVdQCE475yEKcUUPfL4ub
    test-framework-0.8.2.0-5eYG3NRKVE7L7pW0FKysaQ

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

